==> cms-db_v0.7.9.tar.gz: admin/stats.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('');
include('locale.inc.php');
$locale = new LocalizingClass('stats');

if (isset($_GET['nobots']) && $_GET['nobots'] == 'yes') {
	$nobots = 'yes';
} else {
	$nobots = 'no';
}
if (isset($_GET['noversions']) && $_GET['noversions'] == 'yes') {
	$noversions = 'yes';
} else {
	$noversions = 'no';
}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('desc_stats') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
</head>
<body>

<h1><?php locale('desc_stats') ?></h1>
<h2><?php locale('title_browsers') ?></h2>
<?php
$browser_files = array();
$browser_count = 0;
$folder = '../data/stats/browser';
$handle = opendir($folder);
while (false !== ($file = readdir($handle))) {
	if($file != "." && $file != "..") {
		if ($nobots == 'yes' && substr($file, 0, 3) == 'bot') {
			continue;
		}
		$data = file_get_contents('../data/stats/browser/'.$file);
		$data = explode("\n", $data); # 0: Name, 1: Version, 2: Count
		if ($noversions == 'no') {
			$browser_files[] = $data;
		} else {
			$data[1] = '';
			if (array_key_exists($data[0], $browser_files)) {
				$data[2] = $data[2] + $browser_files[$data[0]][2];
			}
			$browser_files[$data[0]] = $data;
		}
	}
}
asort($browser_files);
foreach($browser_files as $data) {
	$browser_count = $browser_count + $data[2];
}
foreach($browser_files as $data) {
	$percent = ( $data[2] / $browser_count ) * 100;
	$percent = round($percent, 1);
	if ($percent >= 5 OR $percent == 4) {
		echo '
		<div style="font-size: 10pt; line-height: 2Opx; margin-top: -1px; width: 750px; clear: both; border: 1px solid #ccc; padding: 5px 0 5px 0; background-image: url(\'stats.png\'); background-repeat: repeat-y">
			<span style="width: 150px; float:left">' . $data[0] . ' ' . $data[1] .'</span>
			<div style="margin-left: 150px; background: #000; height: 20px; width: ' . round($percent*6, 0) . 'px; color: #fff">
				' . $percent . '%
			</div>
		</div>';
	} else {
		echo '
		<div style="font-size: 10pt; line-height: 2Opx; margin-top: -1px; width: 750px; clear: both; border: 1px solid #ccc; padding: 5px 0 5px 0; background-image: url(\'stats.png\'); background-repeat: repeat-y">
			<span style="width: 150px; float:left">' . $data[0] . ' ' . $data[1] .'</span>
			<div style="margin-left: 150px">
				<div style="float: left; margin-right: 5px; background: #000; height: 20px; width: ' . round($percent*6, 0) . 'px; color: #fff"></div>
				<div style="height: 20px; color: #000">' . $percent . '%</div>
			</div>
		</div>';
	}
}
?>
<h2><?php locale('title_os') ?></h2>
<?php
$os_files = array();
$os_count = 0;
$folder = '../data/stats/os';
$handle = opendir($folder);
while (false !== ($file = readdir($handle))) {
	if($file != "." && $file != "..") {
		$os_files[] = file_get_contents('../data/stats/os/'.$file);
	}
}
natcasesort($os_files);
foreach($os_files as $data) {
	$data = explode("\n", $data);
	$os_count = $os_count + $data[1];
}
foreach($os_files as $data) {
	$data = explode("\n", $data);
	$percent = ( $data[1] / $os_count ) * 100;
	$percent = round($percent, 1);
	if ($percent >= 5 OR $percent == 4) {
		echo '
		<div style="font-size: 10pt; line-height: 2Opx; margin-top: -1px; width: 750px; clear: both; border: 1px solid #ccc; padding: 5px 0 5px 0; background-image: url(\'stats.png\'); background-repeat: repeat-y">
			<span style="width: 150px; float:left">' . $data[0] . '</span>
			<div style="margin-left: 150px; background: #000; height: 20px; width: ' . round($percent*6, 0) . 'px; color: #fff">
				' . $percent . '%
			</div>
		</div>';
	} else {
		echo '
		<div style="font-size: 10pt; line-height: 2Opx; margin-top: -1px; width: 750px; clear: both; border: 1px solid #ccc; padding: 5px 0 5px 0; background-image: url(\'stats.png\'); background-repeat: repeat-y">
			<span style="width: 150px; float:left">' . $data[0] . '</span>
			<div style="margin-left: 150px">
				<div style="float: left; margin-right: 5px; background: #000; height: 20px; width: ' . round($percent*6, 0) . 'px; color: #fff"></div>
				<div style="height: 20px; color: #000">' . $percent . '%</div>
			</div>
		</div>';
	}
}
?>
<h2><?php locale('title_actions') ?></h2>
<p>
	<?php if ($nobots == 'no') { ?>
		<a href="stats.php?nobots=yes&noversions=<?php echo $noversions ?>&<?php echo SID ?>"><?php locale('link_hidebots') ?></a>
	<?php } else { ?>
		<a href="stats.php?noversions=<?php echo $noversions ?>&<?php echo SID ?>"><?php locale('link_showbots') ?></a>
	<?php } ?>
</p>
<p>
	<?php if ($noversions == 'no') { ?>
		<a href="stats.php?nobots=<?php echo $nobots ?>&noversions=yes&<?php echo SID ?>"><?php locale('link_hideversions') ?></a>
	<?php } else { ?>
		<a href="stats.php?nobots=<?php echo $nobots ?>&<?php echo SID ?>"><?php locale('link_showversions') ?></a>
	<?php } ?>
</p>
<p>
	<a href="delip.php?<?php echo SID ?>"><?php locale('link_delip') ?></a>
</p>
<p>
	<a href="addip.php?<?php echo SID ?>"><?php locale('link_addip') ?></a>
</p>
<p>
	<a href="delstats.php?<?php echo SID ?>"><?php locale('link_delstats') ?></a>
</p>
<p>
	<?php
	if (isset($_GET['action'])) {
		if ($_GET['action'] == 'delip') {
			locale('desc_delip');
		} elseif ($_GET['action'] == 'addip') {
			locale('desc_addip');
		} elseif ($_GET['action'] == 'delstats') {
			locale('desc_delstats');
		}
	}
	?>
</p>

</body>
</html>

==> cms-db_v0.8.1.tar.gz: admin/stats.php <==
<?php
/*  cms-db  Copyright (C) 2007-2010 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */

define('cms-db', 'backend');

include('checkuser.inc.php');
checkuser('');
include('locale.inc.php');
$locale = new LocalizingClass('stats');

if (isset($_GET['nobots']) && $_GET['nobots'] == 'yes') {
	$nobots = 'yes';
} else {
	$nobots = 'no';
}
if (isset($_GET['noversions']) && $_GET['noversions'] == 'yes') {
	$noversions = 'yes';
} else {
	$noversions = 'no';
}
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('desc_stats') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
<link rel="stylesheet" type="text/css" href="<?php include('mobile.inc.php'); echo mobile() ? 'style-extra-mobile.css' : 'style-extra.css'; ?>" />
<script src="jquery.js" type="text/javascript"></script>
<script src="anchormenu.js" type="text/javascript"></script>
</head>
<body>

<h1><?php locale('desc_stats') ?></h1>

<div class="anchormenu"><span class="leftcorner">&nbsp;</span><ul><li><a href="#browsers" class="nonewtab"><?php locale('title_browsers') ?></a></li><li><a href="#os" class="nonewtab"><?php locale('title_os') ?></a></li><li><a href="#actions" class="nonewtab"><?php locale('title_actions') ?></a></li></ul><span class="rightcorner">&nbsp;</span></div>

<?php
if (isset($_GET['action'])) {
	if ($_GET['action'] == 'delip') {
		echo '<p class="hint">'.locale('desc_delip',true).'</p>';
	} elseif ($_GET['action'] == 'addip') {
		echo '<p class="hint">'.locale('desc_addip',true).'</p>';
	} elseif ($_GET['action'] == 'delstats') {
		echo '<p class="hint">'.locale('desc_delstats',true).'</p>';
	}
}
?>

<div id="browsers">
<h2><?php locale('title_browsers') ?></h2>
<p>
	<?php if ($nobots == 'no') { ?>
		<a href="stats.php?nobots=yes&noversions=<?php echo $noversions ?>&<?php echo SID; csrf_protection_get_html() ?>#browsers" class="nonewtab"><?php locale('link_hidebots') ?></a>
	<?php } else { ?>
		<a href="stats.php?noversions=<?php echo $noversions ?>&<?php echo SID; csrf_protection_get_html() ?>#browsers" class="nonewtab"><?php locale('link_showbots') ?></a>
	<?php } ?>
	 | 
	<?php if ($noversions == 'no') { ?>
		<a href="stats.php?nobots=<?php echo $nobots ?>&noversions=yes&<?php echo SID; csrf_protection_get_html() ?>#browsers" class="nonewtab"><?php locale('link_hideversions') ?></a>
	<?php } else { ?>
		<a href="stats.php?nobots=<?php echo $nobots ?>&<?php echo SID; csrf_protection_get_html() ?>#browsers" class="nonewtab"><?php locale('link_showversions') ?></a>
	<?php } ?>
</p>
<?php
$browser_files = array();
$browser_count = 0;
$folder = '../data/stats/browser';
$handle = opendir($folder);
while (false !== ($file = readdir($handle))) {
	if($file != "." && $file != "..") {
		if ($nobots == 'yes' && substr($file, 0, 3) == 'bot') {
			continue;
		}
		$data = file_get_contents('../data/stats/browser/'.$file);
		$data = explode("\n", $data); # 0: Name, 1: Version, 2: Count
		if ($noversions == 'no') {
			$browser_files[] = $data;
		} else {
			$data[1] = '';
			if (array_key_exists($data[0], $browser_files)) {
				$data[2] = $data[2] + $browser_files[$data[0]][2];
			}
			$browser_files[$data[0]] = $data;
		}
	}
}
asort($browser_files);
foreach($browser_files as $data) {
	$browser_count = $browser_count + $data[2];
}
foreach($browser_files as $data) {
	$percent = ( $data[2] / $browser_count ) * 100;
	$percent = round($percent, 1);
	if ($percent >= 5 OR $percent == 4) {
		echo '
		<div style="font-size: 10pt; line-height: 2Opx; margin-top: -1px; width: 750px; clear: both; border: 1px solid #ccc; padding: 5px 0 5px 0; background-image: url(\'stats.png\'); background-repeat: repeat-y">
			<span style="width: 150px; float:left">' . $data[0] . ' ' . $data[1] .'</span>
			<div style="margin-left: 150px; background: #000; height: 20px; width: ' . round($percent*6, 0) . 'px; color: #fff">
				' . $percent . '%
			</div>
		</div>';
	} else {
		echo '
		<div style="font-size: 10pt; line-height: 2Opx; margin-top: -1px; width: 750px; clear: both; border: 1px solid #ccc; padding: 5px 0 5px 0; background-image: url(\'stats.png\'); background-repeat: repeat-y">
			<span style="width: 150px; float:left">' . $data[0] . ' ' . $data[1] .'</span>
			<div style="margin-left: 150px">
				<div style="float: left; margin-right: 5px; background: #000; height: 20px; width: ' . round($percent*6, 0) . 'px; color: #fff"></div>
				<div style="height: 20px; color: #000">' . $percent . '%</div>
			</div>
		</div>';
	}
}
?>
</div>

<div id="os">
<h2><?php locale('title_os') ?></h2>
<?php
$os_files = array();
$os_count = 0;
$folder = '../data/stats/os';
$handle = opendir($folder);
while (false !== ($file = readdir($handle))) {
	if($file != "." && $file != "..") {
		$os_files[] = file_get_contents('../data/stats/os/'.$file);
	}
}
natcasesort($os_files);
foreach($os_files as $data) {
	$data = explode("\n", $data);
	$os_count = $os_count + $data[1];
}
foreach($os_files as $data) {
	$data = explode("\n", $data);
	$percent = ( $data[1] / $os_count ) * 100;
	$percent = round($percent, 1);
	if ($percent >= 5 OR $percent == 4) {
		echo '
		<div style="font-size: 10pt; line-height: 2Opx; margin-top: -1px; width: 750px; clear: both; border: 1px solid #ccc; padding: 5px 0 5px 0; background-image: url(\'stats.png\'); background-repeat: repeat-y">
			<span style="width: 150px; float:left">' . $data[0] . '</span>
			<div style="margin-left: 150px; background: #000; height: 20px; width: ' . round($percent*6, 0) . 'px; color: #fff">
				' . $percent . '%
			</div>
		</div>';
	} else {
		echo '
		<div style="font-size: 10pt; line-height: 2Opx; margin-top: -1px; width: 750px; clear: both; border: 1px solid #ccc; padding: 5px 0 5px 0; background-image: url(\'stats.png\'); background-repeat: repeat-y">
			<span style="width: 150px; float:left">' . $data[0] . '</span>
			<div style="margin-left: 150px">
				<div style="float: left; margin-right: 5px; background: #000; height: 20px; width: ' . round($percent*6, 0) . 'px; color: #fff"></div>
				<div style="height: 20px; color: #000">' . $percent . '%</div>
			</div>
		</div>';
	}
}
?>
</div>

<div id="actions">
<h2><?php locale('title_actions') ?></h2>
<p>
	<a href="delip.php?<?php echo SID; csrf_protection_get_html() ?>#actions" class="nonewtab"><?php locale('link_delip') ?></a>
</p>
<p>
	<a href="addip.php?<?php echo SID; csrf_protection_get_html() ?>#actions" class="nonewtab"><?php locale('link_addip') ?></a>
</p>
<p>
	<a href="delstats.php?<?php echo SID; csrf_protection_get_html() ?>#actions" class="nonewtab"><?php locale('link_delstats') ?></a>
</p>
</div>

</body>
</html>
